@@ -4,15 +4,13 @@ import math
 import struct
 import time
 from enum import Enum
-from typing import Optional
-
+from pymobiledevice3.exceptions import PyMobileDevice3Exception, IRecvNoDeviceConnectedError
+from pymobiledevice3.irecv_devices import IRECV_DEVICES, IRecvDevice
 from tqdm import trange
+from typing import Optional
 from usb.core import find, Device, USBError
 from usb.util import get_string
 
-from pymobiledevice3.exceptions import PyMobileDevice3Exception
-from pymobiledevice3.irecv_devices import IRECV_DEVICES, IRecvDevice
-
 USB_TIMEOUT = 10000
 IRECV_TRANSFER_SIZE_RECOVERY = 0x8000
 IRECV_TRANSFER_SIZE_DFU = 0x800
@@ -83,6 +81,14 @@ class IRecv:
     def board_id(self):
         return int(self._device_info['BDID'], 16)
 
+    @property
+    def serial_number(self) -> int:
+        return int(self._device_info['SRNM'], 16)
+
+    @property
+    def iboot_version(self) -> str:
+        return self._device_info['SRTG']
+
     @property
     def is_image4_supported(self):
         return self.ibfl & IBOOT_FLAG_IMAGE4_AWARE
@@ -225,6 +231,8 @@ class IRecv:
         self._device_info = {}
         self.mode = None
         self._find(ecid=ecid, timeout=timeout, is_recovery=is_recovery)
+        if self._device is None:
+            raise IRecvNoDeviceConnectedError('Failed to find a connected iDevice')
         self._populate_device_info()
 
         self.ap_nonce = self._copy_nonce_with_tag('NONC')
@@ -279,7 +287,7 @@ class IRecv:
     def _populate_device_info(self):
         for component in self._device.serial_number.split(' '):
             k, v = component.split(':')
-            if k == 'SRNM' and '[' in v:
+            if k in ('SRNM', 'SRTG') and '[' in v:
                 # trim the `[]`
                 v = v[1:-1]
             self._device_info[k] = v
@@ -287,6 +295,12 @@ class IRecv:
     def __str__(self):
         return str(self._device_info)
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        del self._device
+
 
 def main():
     print(IRecv())
