@@ -19,6 +19,7 @@ from pymobiledevice3.exceptions import LockdownError, SetProhibitedError, Passco
     ConnectionTerminatedError, IncorrectModeError, FatalPairingError, MissingValueError, CannotStopSessionError, \
     NotPairedError, PairingError, InvalidHostIDError, PasswordRequiredError, StartServiceError, \
     PairingDialogResponsePendingError, UserDeniedPairingError, ConnectionFailedError
+from pymobiledevice3.irecv_devices import IRECV_DEVICES
 from pymobiledevice3.service_connection import ServiceConnection, Medium
 from pymobiledevice3.usbmux import PlistMuxConnection
 from pymobiledevice3.utils import sanitize_ios_version
@@ -130,7 +131,7 @@ class LockdownClient(object):
         self.paired = False
         self.session_id = None
         self.host_id = self.generate_host_id(local_hostname)
-        self.system_buid = SYSTEM_BUID
+        self.system_buid = self.get_system_buid()
         self.label = client_name
         self.pair_record = pair_record
         self.pairing_records_cache_folder = pairing_records_cache_folder
@@ -270,6 +271,24 @@ class LockdownClient(object):
     def sanitized_ios_version(self) -> str:
         return sanitize_ios_version(self.product_version)
 
+    @property
+    def hardware_model(self) -> str:
+        for irecv_device in IRECV_DEVICES:
+            if irecv_device.product_type == self.product_type:
+                return irecv_device.hardware_model
+
+    @property
+    def board_id(self) -> int:
+        for irecv_device in IRECV_DEVICES:
+            if irecv_device.product_type == self.product_type:
+                return irecv_device.board_id
+
+    @property
+    def chip_id(self) -> int:
+        for irecv_device in IRECV_DEVICES:
+            if irecv_device.product_type == self.product_type:
+                return irecv_device.chip_id
+
     def set_language(self, language: str) -> None:
         self.set_value(language, key='Language', domain='com.apple.international')
 
@@ -286,6 +305,15 @@ class LockdownClient(object):
     def enter_recovery(self):
         return self._request('EnterRecovery')
 
+    def get_system_buid(self) -> str:
+        result = SYSTEM_BUID
+        if self.medium == Medium.USBMUX:
+            client = usbmux.create_mux()
+            if isinstance(client, PlistMuxConnection):
+                result = client.get_buid()
+            client.close()
+        return result
+
     def stop_session(self) -> Mapping:
         if self.session_id and self.service:
             response = self._request('StopSession', {'SessionID': self.session_id})
