@@ -3,13 +3,11 @@ import plistlib
 import socket
 import sys
 import time
-from dataclasses import dataclass
-from typing import List, Optional, Mapping
-
 from construct import Struct, Prefixed, Int32ul, GreedyBytes, StreamError, Int16ul, CString, Padding, FixedSized, \
     Enum, Const, Switch, this
-
+from dataclasses import dataclass
 from pymobiledevice3.exceptions import MuxException, MuxVersionError, NotPairedError, UsbmuxConnectionError
+from typing import List, Optional, Mapping
 
 usbmuxd_version = Enum(Int32ul,
                        BINARY=0,
@@ -150,9 +148,10 @@ class MuxConnection:
     def create():
         # first attempt to connect with possibly the wrong version header (plist protocol)
         sock = MuxConnection.create_usbmux_socket()
+
         message = usbmuxd_request.build({
-            'header': {'version': usbmuxd_version.PLIST, 'message': usbmuxd_msgtype.LISTEN, 'tag': 1},
-            'data': b''
+            'header': {'version': usbmuxd_version.PLIST, 'message': usbmuxd_msgtype.PLIST, 'tag': 1},
+            'data': plistlib.dumps({'MessageType': 'ReadBUID'})
         })
         sock.send(message)
         response = usbmuxd_response.parse_stream(sock)
@@ -298,10 +297,11 @@ class PlistMuxConnection(BinaryMuxConnection):
         super().__init__(sock)
         self._version = usbmuxd_version.PLIST
 
-    def listen(self):
+    def listen(self) -> None:
         self._send_receive({'MessageType': 'Listen'})
 
     def get_pair_record(self, serial: str) -> Mapping:
+        # serials are saved inside usbmuxd without '-'
         self._send({'MessageType': 'ReadPairRecord', 'PairRecordID': serial})
         response = self._receive(self._tag - 1)
         pair_record = response.get('PairRecordData')
@@ -309,7 +309,7 @@ class PlistMuxConnection(BinaryMuxConnection):
             raise NotPairedError('device should be paired first')
         return plistlib.loads(pair_record)
 
-    def get_device_list(self, timeout: float = None):
+    def get_device_list(self, timeout: float = None) -> None:
         """ get device list synchronously without waiting the timeout """
         self.devices = []
         self._send({'MessageType': 'ListDevices'})
@@ -328,6 +328,7 @@ class PlistMuxConnection(BinaryMuxConnection):
         return self._receive(self._tag - 1)['BUID']
 
     def save_pair_record(self, serial: str, device_id: int, record_data: bytes):
+        # serials are saved inside usbmuxd without '-'
         self._send_receive({'MessageType': 'SavePairRecord',
                             'PairRecordID': serial,
                             'PairRecordData': record_data,
